\version "2.13.4"
\include "deutsch.ly"
#(set-default-paper-size "a4")
#(ly:set-option 'point-and-click #t)


%%%%%%%%%%  This provides joint rests 
%%%%%%%%%%  for the voices of the right hand in the realisation 
%%%%%%%%%%  of the figured bass
#(define (rest-score r)
  (let ((score 0)
        (yoff (ly:grob-property-data r 'Y-offset))
        (sp (ly:grob-property-data r 'staff-position)))
    (if (number? yoff)
        (set! score (+ score 2))
        (if (eq? yoff 'calculation-in-progress)
            (set! score (- score 3))))
    (and (number? sp)
         (<= 0 2 sp)
         (set! score (+ score 2))
         (set! score (- score (abs (- 1 sp)))))
    score))

#(define (merge-rests-on-positioning grob)
  (let* ((can-merge #f)
         (elts (ly:grob-object grob 'elements))
         (num-elts (and (ly:grob-array? elts)
                        (ly:grob-array-length elts)))
         (two-voice? (= num-elts 2)))
    (if two-voice?
        (let* ((v1-grob (ly:grob-array-ref elts 0))
               (v2-grob (ly:grob-array-ref elts 1))
               (v1-rest (ly:grob-object v1-grob 'rest))
               (v2-rest (ly:grob-object v2-grob 'rest)))
          (and
           (ly:grob? v1-rest)
           (ly:grob? v2-rest)              
           (let* ((v1-duration-log (ly:grob-property v1-rest 'duration-log))
                  (v2-duration-log (ly:grob-property v2-rest 'duration-log))
                  (v1-dot (ly:grob-object v1-rest 'dot))
                  (v2-dot (ly:grob-object v2-rest 'dot))
                  (v1-dot-count (and (ly:grob? v1-dot)
                                     (ly:grob-property v1-dot 'dot-count -1)))
                  (v2-dot-count (and (ly:grob? v2-dot)
                                     (ly:grob-property v2-dot 'dot-count -1))))
             (set! can-merge
                   (and 
                    (number? v1-duration-log)
                    (number? v2-duration-log)
                    (= v1-duration-log v2-duration-log)
                    (eq? v1-dot-count v2-dot-count)))
             (if can-merge
                 ;; keep the rest that looks best:
                 (let* ((keep-v1? (>= (rest-score v1-rest)
                                      (rest-score v2-rest)))
                        (rest-to-keep (if keep-v1? v1-rest v2-rest))
                        (dot-to-kill (if keep-v1? v2-dot v1-dot)))
                   ;; uncomment if you're curious of which rest was chosen:
                   ;;(ly:grob-set-property! v1-rest 'color green)
                   ;;(ly:grob-set-property! v2-rest 'color blue)
                   (ly:grob-suicide! (if keep-v1? v2-rest v1-rest))
                   (if (ly:grob? dot-to-kill)
                       (ly:grob-suicide! dot-to-kill))
                   (ly:grob-set-property! rest-to-keep 'direction 0)
                   (ly:rest::y-offset-callback rest-to-keep)))))))
    (if can-merge
        #t
        (ly:rest-collision::calc-positioning-done grob))))


%%%%%%%%%%%%%%%  Makros  %%%%%%%%%%%%%%%%%%
tr = ^\markup { \bold {+}}
pad =  { \once \override Script #'padding = #1.0 }
% kleine Noten
kl =  \set fontSize = #-4 
  
% normal große Noten
nm =   \set fontSize = #0

% bei Verzierungen: Hälse kürzen, Hals nach unten, kleine Noten
skd =  { \once \override Stem #'length-fraction = #0.6 \once \override Stem #'direction = #DOWN \once \set fontSize = #-3   }
skxd =  { \override Stem #'length-fraction = #0.4  \override Stem #'direction = #DOWN  \set fontSize = #-3   }
skad = { \once \override Stem #'length-fraction = #0.7 \once \override Stem #'direction = #DOWN \once \set fontSize = #-3   }
sknd = { \once \override Stem #'length-fraction = #1 \once \override Stem #'direction = #DOWN \once \set fontSize = #-3   }
sku = { \once \override Stem #'length-fraction = #0.6 \once \override Stem #'direction = #UP \once \set fontSize = #-3   }
skau = { \once \override Stem #'length-fraction = #0.8 \once \override Stem #'direction = #UP \once \set fontSize = #-3   }
sknu = { \once \override Stem #'length-fraction = #1 \once \override Stem #'direction = #UP \once \set fontSize = #-3   }

sn =   { \override Stem #'length-fraction = #1  \set fontSize = #1 }  %normale Länge

%  Unterbalken geändert: statt 3 * 2 16-tel nun 2 * 3 16-tel
qbeam = {
  \set subdivideBeams = ##t
  \set Staff.beatLength = #(ly:make-moment 3 16)
  \set Staff.beatLength = #(ly:make-moment 3 8)
}
% Unterbalken gemäß Standard
nbeam = {
  \set Staff.beatLength = #(ly:make-moment 1 8)
  \set subdivideBeams = ##f
}

% Linien im Generalbass ein und ausschalten
lj = \set useBassFigureExtenders = ##t
ln = \set useBassFigureExtenders = ##f

% Transparente Ziffer
zt = {  \once \override FiguredBass.BassFigure #'transparent = ##t
        \once \override FiguredBass.BassFigure #'X-extent = #'(0 . 0) }

%%%%%%%%%%%%% Ende Makros %%%%%%%%%%%%%%%%%

\paper {
  myStaffSize = #20

  #(define fonts
    (make-pango-font-tree "Times New Roman"
                          "Nimbus Sans"
                          "Luxi Mono"
                           (/ myStaffSize 20)))

  line-width = 18\cm
  ragged-last-bottom = ##f
 

}
#(set-global-staff-size 18)

\header  { 
  title =    \markup  { "III." \raise #1.0 \bold \small{ "e" } " Suite" }
  subsubtitle = \markup  { "aus / de / from \"Deuxième Livre de Pièces pour la flûte traversière avec la basse continue\" (1710) " }
  composer = \markup \override #'(baseline-skip . 2) \right-column {"\n" "\n" "Michel de La Barre" \tiny "(1675? - 1745)"  }
  arranger =   \markup {  \tiny "Published by Fr.-R. Kuhnen"}
  copyright = \markup {  "© Copyright 2010 by Franz-Rudolf Kuhnen - http://noten.kuhnen-musik.de (Rev.: 01-201000514)"}  
  }
  
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              1. Mouvement
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\score {

 <<   
   \overrideBeamSettings #'Score #'(4 . 4) #'end #'((* . (1 1 1 1)))
   \override Score.BarNumber  #'font-shape = #'italic
   \override Score.BarNumber  #'font-series = #'bold
   \override Score.RehearsalMark
  #'break-visibility = #begin-of-line-invisible
  
 \new ChoirStaff  <<
  \new Staff  
    \include "stimmen/03_1-01-solo.ly"
   
  \new Staff
    \include "stimmen/03_1-03-lh.ly"
 
  \new FiguredBass \figuremode 
    \include "stimmen/03_1-04-figures.ly"
 >>

>>
 \layout {
   indent = 0\cm
% \context {
%    \Staff
%   \override TimeSignature #'style = #'single-digit
% }

 }

 \header { 
   piece=   \markup \column {  \override #'(font-size . 3) \italic "Allemande"}
 }
 
}

\pageTurn

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              2. Mouvement
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\score {

 <<    
   \overrideBeamSettings #'Score #'(2 . 2) #'end
     #'(((1 . 8) . (2 2 2 2)))
%    \overrideBeamSettings #'Score #'(2 . 2) #'end #'((1 . 8 (2 2)))
   \override Score.BarNumber  #'font-shape = #'italic
   \override Score.BarNumber  #'font-series = #'bold
   \override Score.RehearsalMark
  #'break-visibility = #begin-of-line-invisible
  
 \new ChoirStaff  <<
   
  \new Staff  
    \include "stimmen/03_2-01-solo.ly"
  
  \new Staff
    \include "stimmen/03_2-03-lh.ly"
   
  \new FiguredBass \figuremode 
    \include "stimmen/03_2-04-figures.ly"

 >>
>>
 \layout {
   indent = 0\cm
  \context {
     \Staff
     \override TimeSignature #'style = #'single-digit
   }
 }

 \header { 
   piece=   \markup \column {  \override #'(font-size . 3) \italic "Rondeau"}
 }
 
}

\pageTurn

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              3. Mouvement
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\score {

 <<    
   \overrideBeamSettings #'Score #'(2 . 2) #'end
     #'(((1 . 8) . (2 2 2 2)))
%    \overrideBeamSettings #'Score #'(2 . 2) #'end #'((1 . 8 (2 2)))
   \override Score.BarNumber  #'font-shape = #'italic
   \override Score.BarNumber  #'font-series = #'bold
   \override Score.RehearsalMark
  #'break-visibility = #begin-of-line-invisible
  
 \new ChoirStaff  <<

  \new Staff  
    \include "stimmen/03_3-01-solo.ly"
  \new Staff
    \include "stimmen/03_3-03-lh.ly"
 
  \new FiguredBass \figuremode 
    \include "stimmen/03_3-04-figures.ly"

 >>
>>
 \layout {
   indent = 0\cm
  \context {
     \Staff
     \override TimeSignature #'style = #'single-digit
   }
 }

 \header { 
   piece=   \markup \column {  \override #'(font-size . 3) \italic "Sarabande"}
 }
 
}

\pageTurn

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              4. Mouvement
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\score {

 <<    
   \overrideBeamSettings #'Score #'(2 . 2) #'end
     #'(((1 . 8) . (2 2 2 2)))
%    \overrideBeamSettings #'Score #'(2 . 2) #'end #'((1 . 8 (2 2)))
   \override Score.BarNumber  #'font-shape = #'italic
   \override Score.BarNumber  #'font-series = #'bold
   \override Score.RehearsalMark
  #'break-visibility = #begin-of-line-invisible
  
 \new ChoirStaff  <<

  \new Staff  
    \include "stimmen/03_4-01-solo.ly"
  \new Staff
    \include "stimmen/03_4-03-lh.ly"
  
  \new FiguredBass \figuremode 
    \include "stimmen/03_4-04-figures.ly"

 >>
>>
 \layout {
   indent = 0\cm
%   \context {
%      \Staff
%      \override TimeSignature #'style = #'single-digit
%    }
 }

 \header { 
   piece=   \markup \column {  \override #'(font-size . 3) \italic "Gigue"}
 }
 
}

\pageTurn